fn count_skipped(
working: &BTreeMap<(String, Vec<(String, Option<String>)>, Option<u64>, Option<MetricKind>, bool, String), i64>,
) -> u64Expand description
Counts live working rows dropped for an unsupported metric_type, an invalid Prometheus
metric or label name, or a null or empty label value.