count_skipped

Function count_skipped 

fn count_skipped(
    working: &BTreeMap<(String, Vec<(String, String)>, Option<u64>, Option<MetricKind>, bool, String), i64>,
) -> u64
Counts live working rows dropped for an unsupported metric_type or an invalid Prometheus metric or label name.